pub type HdKeyPaths = BTreeMap<PublicKey, KeySource>;Expand description
Alias for the type of maps that represent derivation paths in a psbt::Input or
psbt::Output
Aliased Type
struct HdKeyPaths { /* private fields */ }pub type HdKeyPaths = BTreeMap<PublicKey, KeySource>;Alias for the type of maps that represent derivation paths in a psbt::Input or
psbt::Output
struct HdKeyPaths { /* private fields */ }